package com.ozs.plan.service;


import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.core.domain.model.LoginUser;
import com.ozs.plan.doman.PlanYears;
import com.ozs.plan.doman.vo.requestVo.PlanYearsStandardVo;

import java.util.List;

/**
 * 系统访问日志情况信息 服务层
 *
 * @author bu
 */
public interface PlanYearsService {

    /**
     * 查询年度计划记录集合
     *
     * @param vo 年度计划请求对象
     * @return 年度计划记录集合
     */
    public List<PlanYears> selectPlanYearsList(PlanYearsStandardVo vo);

    /**
     * 查询年度计划记录集合
     *
     * @param vo 年度计划请求对象
     * @return 年度计划记录集合
     */
    public List<PlanYears> selectPlanYearsExamineList(PlanYearsStandardVo vo);

    /**
     * 创建年度计划
     *
     * @param yearsStandardVo 年度计划请求对象
     */
    public AjaxResult insertPlanYears(PlanYearsStandardVo yearsStandardVo);

    /**
     * 批量删除年度计划
     *
     * @param planIds 需要删除的年度计划ID
     * @return 结果
     */
    public AjaxResult deletePlanYearsByIds(Long[] planIds);

    /**
     * 批量删除年度计划
     *
     * @param planYearId 需要删除的年度计划ID
     * @return 结果
     */
    public AjaxResult deletePlanYearsById(Long planYearId);

    /**
     * 根据id获取年度计划信息
     *
     * @param yearsStandardVo 年度计划请求对象
     * @return 结果
     */
    public AjaxResult view(PlanYearsStandardVo yearsStandardVo);

    /**
     * 修改年度计划
     *
     * @param yearsStandardVo 修改年度计划请求对象
     * @return 结果
     */
    public AjaxResult update(PlanYearsStandardVo yearsStandardVo);

    /**
     * 导入年度计划数据
     *
     * @return 结果
     */
    public String importPlanYears(List<PlanYears> planYears, boolean isUpdateSupport, LoginUser loginUser);

    /**
     * 提交年度计划
     *
     * @param yearsStandardVo 提交年度计划请求对象
     * @return 结果
     */
    public AjaxResult commit(PlanYearsStandardVo yearsStandardVo);

    /**
     * 审核年度计划
     *
     * @param yearsStandardVo 需要审核的年度计划
     * @return 结果
     */
    public AjaxResult reviewTo(PlanYearsStandardVo yearsStandardVo);

    /**
     * 审核年度计划退回
     *
     * @param yearsStandardVo 需要审核的年度计划
     * @return 结果
     */
    public AjaxResult reviewReturn(PlanYearsStandardVo yearsStandardVo);

    /**
     * 申请修改年度计划
     *
     * @param yearsStandardVo 需要修改的年度计划
     * @return 结果
     */
    public AjaxResult appUpdate(PlanYearsStandardVo yearsStandardVo);

    /**
     * 发函催告
     *
     * @param yearsStandardVo 年度计划
     * @return 结果
     */
    AjaxResult sendLetter(PlanYearsStandardVo yearsStandardVo);

    /**
     * 上传计划关联文件后保存文件信息
     *
     * @param yearsStandardVo 年度计划
     * @return 结果
     */
    AjaxResult upLoadPlanFile(PlanYearsStandardVo yearsStandardVo);

    /**
     * 下载计划关联文件
     *
     * @param yearsStandardVo 年度计划
     * @return 结果
     */
    AjaxResult downLoadPlanFile(PlanYearsStandardVo yearsStandardVo);
}
